@@ -1,6 +1,6 @@
 import re
 
-from multidecoder.analyzers.vba import CREATE_OBJECT_RE, find_createobject
+from multidecoder.analyzers.vba import CREATE_OBJECT_RE, find_createobject, find_strreverse
 from multidecoder.hit import Hit
 
 
@@ -17,3 +17,11 @@ def test_find_wscript():
     assert find_createobject(text) == [
         Hit(b'CreateObject("WScript.Shell")', '', 4, len(text))
     ]
+
+
+def test_find_strreverse_empty():
+    assert find_strreverse(b'') == []
+
+
+def test_find_strreverse_duck():
+    assert find_strreverse(b'StrReverse("kcud")')[0].value == b'duck'
